@@ -95,6 +95,9 @@ ibus_rime_create_session (IBusRimeEngine *rime_engine)
       g_ibus_rime_settings.preedit_style == PREEDIT_STYLE_COMPOSITION &&
       g_ibus_rime_settings.cursor_type == CURSOR_TYPE_INSERT;
   rime_api->set_option(rime_engine->session_id, "soft_cursor", !inline_caret);
+  // Define arrow key actions in the selector component.
+  Bool horizontal = g_ibus_rime_settings.lookup_table_orientation == IBUS_ORIENTATION_HORIZONTAL;
+  rime_api->set_option(rime_engine->session_id, "_horizontal", horizontal);
 }
 
 static void
@@ -201,6 +204,15 @@ ibus_rime_engine_focus_out (IBusEngine *engine)
 static void
 ibus_rime_engine_reset (IBusEngine *engine)
 {
+  IBusRimeEngine *rime_engine = (IBusRimeEngine *)engine;
+
+  if (rime_engine->session_id) {
+    rime_api->clear_composition(rime_engine->session_id);
+    // Clear uncommited contents of the pre-edit buffer.
+    ibus_engine_update_preedit_text_with_mode(
+        engine, ibus_text_new_from_static_string(""), 0, FALSE, IBUS_ENGINE_PREEDIT_CLEAR);
+    ibus_rime_engine_update(rime_engine);
+  }
 }
 
 static void
